import java.io.*;
import java.util.*;

class park_judge
{
    public Scanner sc;
    public PrintStream ps;

    public String toString()
    {
        return "park_judge";
    }

    // A Tree - its (x,y) location, and whether or not it can be seen.
    public class Tree
    {
        public int x, y;
        public boolean seen;

        public Tree( int xx, int yy )
        {   
            seen = false;
            x=xx; y=yy;
        }

        public String toString()
        {
            return "{Tree:seen=" + seen + ", x=" + x + ", y=" + y + "}";
        }
    };

    // A comparator to sort trees by x, then y.
    public class XComparator implements Comparator<Tree>
    {
        public int compare( Tree a, Tree b )
        {
            int diff = a.x-b.x;
            if( diff==0 ) diff = a.y-b.y;
            return diff;
        }

        public boolean equals( Object o )
        {
            return o==this;
        }
    };

    // A comparator to sort trees by y, then x.
    public class YComparator implements Comparator<Tree>
    {
        public int compare( Tree a, Tree b )
        {
            int diff = a.y-b.y;
            if( diff==0 ) diff = a.x-b.x;
            return diff;
        }

        public boolean equals( Object o )
        {
            return o==this;
        }
    };

    public void doit() throws Exception
    {
        sc = new Scanner( System.in );
        ps = System.out;

        // Don't need to create these every time
        XComparator xc = new XComparator();
        YComparator yc = new YComparator();

        for(;;)
        {
            // Read n & m, break if done
            int n = sc.nextInt();
            int m = sc.nextInt();
            if( n==0 && m==0  ) break;

            // Read in the trees
            Tree trees[] = new Tree[n];
            for( int i=0; i<n; i++ )
            {
                int x = sc.nextInt();
                int y = sc.nextInt();
                trees[i] = new Tree( x, y );
            }

            // OK, now prepare to read in the paths. 
            // Separate out xpaths (vertical) from ypaths (horizontal).
            // m is the most there could be in either direction
            int xpaths[] = new int[m];
            int ypaths[] = new int[m];

            // Keep a count of how many there actually are in each directtion
            int nxs = 0;
            int nys = 0;

            for( int i=0; i<m; i++ )
            {
                // tokens[0] = 'x' | 'y'
                // tokens[1] = value
                String tokens[] = sc.next().split( "=" );
                int value = Integer.parseInt( tokens[1] );

                if( tokens[0].toLowerCase().equals( "x" ) )
                {
                    xpaths[nxs++] = value;
                }
                else if( tokens[0].toLowerCase().equals( "y" ) )
                {
                    ypaths[nys++] = value;
                }
                else
                {
                    System.out.println( "PANIC!! token is: " + tokens[0] );
                }
            }

            // Shorten up the path arrays to their actual lengths, and sort them
            int xs[] = Arrays.copyOf( xpaths, nxs );
            Arrays.sort( xs );
            int ys[] = Arrays.copyOf( ypaths, nys );
            Arrays.sort( ys );

            // Count of the number of visible trees
            int visible = 0;

            // This will be the x coord of a vertical path,
            // or the y coord of a horizontal path.
            int path;

            // Sort the trees by x's, then y's, so that all of the trees with
            // the same x coord will be grouped together, and sorted by y
            Arrays.sort( trees, xc );

            for( int i=0; i<n; i++ )
            {
                // Find the nearest path going horizontally at a constant y
                // The tree will lie between ys[index-1] and ys[index]
                int index = -Arrays.binarySearch( ys, trees[i].y )-1;

                // This can only happen if the data is messed up, and there are trees on paths.
                if( index<0 ) 
                {
                    System.out.println( "PANIC!! Tree on a path!" );
                    trees[i].seen = true;
                    continue;
                }

                // Check to see if there's a path below this tree
                if( index>0 )
                {
                    path = ys[index-1];

                    // Can you see this tree from this path?
                    // You can, if there's no other tree blocking it.
                    //
                    // So, if there's no previous tree, 
                    // OR the previous tree has a different x, 
                    // OR the previous tree is below the path,
                    // then we can see this tree from this path.
                    if( i==0 || trees[i-1].x!=trees[i].x || trees[i-1].y<path )
                    {
                        trees[i].seen = true;
                        ++visible;
                    }
                }

                // Check to see if there's a path above this tree. 
                // Don't count already seen trees twice.
                if( !trees[i].seen && index<nys )
                {
                    path = ys[index];

                    // Can you see this tree from this path?
                    //
                    // If there's no next tree, 
                    // OR the next tree has a different x, 
                    // OR the next tree is above the path,
                    // then we can see this tree from this path.
                    if( i==(n-1) || trees[i+1].x!=trees[i].x || trees[i+1].y>path )
                    {
                        trees[i].seen = true;
                        ++visible;
                    }
                }
            }

            // Now, Sort by y's, then x's, so that all of the trees with
            // the same y coord will be grouped together, and sorted by x
            Arrays.sort( trees, yc );

            // Don't count already seen trees twice.
            for( int i=0; i<n; i++ ) if( !trees[i].seen )
            {
                // Find the nearest path going horizontally at a constant y.
                // The tree will be between xs[index-1] and xs[index]
                int index = -Arrays.binarySearch( xs, trees[i].x )-1;

                // This can only happen if the data is messed up, and there are trees on paths.
                if( index<0 ) 
                {
                    System.out.println( "PANIC!! Tree on a path!" );
                    trees[i].seen = true;
                    continue;
                }

                // Check to see if there's one before
                if( index>0 )
                {
                    path = xs[index-1];

                    // Can you see this tree from this path?
                    if( i==0 || trees[i-1].y!=trees[i].y || trees[i-1].x<path )
                    {
                        trees[i].seen = true;
                        ++visible;
                    }
                }

                // Check to see if there's one after
                if( !trees[i].seen && index<nxs )
                {
                    path = xs[index];

                    // Can you see this tree from this path?
                    if( i==(n-1) || trees[i+1].y!=trees[i].y || trees[i+1].x>path )
                    {
                        trees[i].seen = true;
                        ++visible;
                    }
                }
            }

            // That's it. Now, just print the result.
            ps.println( visible );
        }
    }

	public static void main(String[] args) throws Exception
	{
		new park_judge().doit();
	}
}
